local _,stash = ...
local L = stash.localization

stash.constants = {

    IS_CLASSIC = WOW_PROJECT_ID == WOW_PROJECT_CLASSIC or WOW_PROJECT_ID == WOW_PROJECT_BURNING_CRUSADE_CLASSIC,

    -- min/max dimensions of frame
    MIN_RESIZE_WIDTH = 220,
    MIN_RESIZE_HEIGHT = 256,
    MAX_RESIZE_WIDTH = 1024,
    MAX_RESIZE_HEIGHT = 1024,

    -- sort flag for stash.info.SortFound
    SORT_FOUND_LOCATIONS = 1,
    SORT_FOUND_MONEY = 2,

    -- left mouse button inline texture
    LMB = "\124TInterface\\TutorialFrame\\UI-Tutorial-Frame:0:0:0:0:512:512:10:65:228:283\124t", 

    -- colors for tooltips
    HEX_WHITE = "\124cffffffff",
    HEX_RED = "\124cffff2020",
    HEX_GREEN = "\124cff73D973",
    HEX_BLUE = "\124cff88bbff",
    HEX_NEUTRAL = "\124cffffbb88",
    HEX_GOLD = "\124cffffd200",
    HEX_GREY = "\124cffa0a0a0",

    -- indexes into a stash.info.items itemID table
    INFO_COUNT = 1,
    INFO_NAME = 2,
    INFO_ICON = 3,
    INFO_RARITY = 4,
    INFO_TYPE = 5,
    INFO_SUBTYPE = 6,
    INFO_EQUIPSLOT = 7,

    -- indexes into a stash.info.found ordered sub-table
    FOUND_REALM = 1,
    FOUND_FACTION = 2,
    FOUND_PLAYER = 3,
    FOUND_LOCATION = 4,
    FOUND_COUNT = 5,

    -- delay times
    UI_UPDATE_DELAY = 0.25, -- seconds until a stash.ui:UpdateNow() is run after any stash.ui:Update() is called
    DATA_CACHE_DELAY = 0.15, -- seconds until a re-scan after items are found to not be data cached
    BANK_OPEN_DELAY = 0.1, -- seconds after bank is opened before a scan of contents done
    TOOLTIP_LOCATION_DELAY = 0.1, -- seconds after a tooltip is shown before locations are appended to it

    -- making our own copy of ITEM_QUALITY_COLORS to make the rare blue a bit brighter (down below)
    QUALITY_COLORS = CopyTable(ITEM_QUALITY_COLORS),

    -- the color of names based on their faction
    FACTION_COLORS = {
        Alliance = "\124cff88bbff",
        Horde = "\124cffff8888",
        Neutral = "\124cffffd280"
    },

    -- location constants; anytime a new location is tracked it needs to be added here and in the lookup below
    LOCATIONS = {
        worn = {
            name = L["Worn"],
            phrase = L["%s %s%s on %s's person"],
            icon = "\124TInterface\\Icons\\INV_Shirt_Blue_01:0:0:0:0:64:64:5:59:5:59\124t"
        },
        bags = {
            name = L["Inventory"],
            phrase = L["%s %s%s in %s's inventory"],
            icon = "\124TInterface\\Icons\\INV_Misc_Bag_08:0:0:0:0:64:64:5:59:5:59\124t"
        },
        bank = {
            name = L["Bank"],
            phrase = L["%s %s%s in %s's bank"],
            icon = "\124TInterface\\Icons\\INV_Misc_Bag_07_Red:0:0:0:0:64:64:5:59:5:59\124t"
        },
        reagents = {
            name = L["Reagents Bank"],
            phrase = L["%s %s%s in %s's reagents bank"],
            icon = "\124TInterface\\Icons\\INV_Misc_Bag_CenarionHerbBag:0:0:0:0:64:64:5:59:5:59\124t"
        },
        currency = {
            name = L["Currency"],
            phrase = L["%s %s%s in %s's currency"],
            icon = "\124TInterface\\Icons\\INV_Misc_ElvenCoins:0:0:0:0:64:64:5:59:5:59\124t"
        },
        mail = {
            name = L["Mail"],
            phrase = L["%s %s%s in %s's mail"],
            icon = "\124TInterface\\Icons\\INV_Letter_15:0:0:0:0:64:64:5:59:5:59\124t"
        },
        void = {
            name = L["Void Storage"],
            phrase = L["%s %s%s in %s's void strorage"],
            icon = "\124TInterface\\Icons\\Spell_Priest_Void Blast:0:0:0:0:64:64:5:59:5:59\124t"
        },
        guild = { -- NYI
            name = L["Guild Bank"],
            phrase = L["%s %s%s in %s guild bank"],
            icon = "\124TInterface\\Icons\\ACHIEVEMENT_GUILDPERK_MOBILEBANKING:0:0:0:0:64:64:5:59:5:59\124t"
        }
    },

    -- for quickly translating localized location names back and forth to/from actual names
    LOCATION_LOOKUP = {
        worn = L["Worn"],
        bags = L["Inventory"],
        bank = L["Bank"],
        reagents = L["Reagents Bank"],
        currency = L["Currency"],
        mail = L["Mail"],
        void = L["Void Storage"],
        guild = L["Guild Bank"]
    },
    LOCATION_REVERSE_LOOKUP = {
        [L["Worn"]] = "worn",
        [L["Inventory"]] = "bags",
        [L["Bank"]] = "bank",
        [L["Reagents Bank"]] = "reagents",
        [L["Currency"]] = "currency",
        [L["Mail"]] = "mail",
        [L["Void Storage"]] = "void",
        [L["Guild Bank"]] = "guild"
    },

    PET_CAGE_ITEMID = 82800,

    -- string inline texture for red questionmark if ever needed
    UNKNOWN_ICON = "\124TInterface\\Icons\\INV_Misc_QuestionMark:0\124t",

    -- current mode of the filter pullout panel (also index into itemsPanel.filterPanelConfigs)
    FILTER_PANEL_NARROW = 1,
    FILTER_PANEL_NORMAL = 2,
    FILTER_PANEL_WIDE = 3,
    FILTER_PANEL_ULTRAWIDE = 4,

    FILTER_DROPDOWN_HEIGHT = 24,
    FILTER_DROPDOWN_PADDING = 1,

     -- identifiers for the type of menus in filterPanel
    FILTER_LOCATION_MENU = 1,
    FILTER_TYPE_MENU = 2,

    -- time before menus close if mouse is not over
    MENU_CLOSE_DELAY = 2,

    RESET_MENU_ITEM = L["\124cffffd200Reset"],

    -- time before tooltips will resume after being paused
    PAUSE_TOOLTIP_TIMER = 0.1,

    -- angle of initial minimap button position
    DEFAULT_MINIMAP_POSITION = -65,

    -- void storage constants
    VOID_STORAGE_MAX_TABS = 2,
    VOID_STORAGE_MAX_SLOTS = 80,

}

-- making the rare blue a bit brighter
stash.constants.QUALITY_COLORS[3].r = 0.125 -- min(1,rarityColors[Enum.ItemQuality.Rare].r+0.125)
stash.constants.QUALITY_COLORS[3].g = 0.56422 -- min(1,rarityColors[Enum.ItemQuality.Rare].g+0.125)
stash.constants.QUALITY_COLORS[3].b = 0.99166 -- min(1,rarityColors[Enum.ItemQuality.Rare].b+0.125)
stash.constants.QUALITY_COLORS[3].hex = "\124cff2090fd"
